@@ -17,7 +17,7 @@ int main(int argc, char** argv) {
 
   using namespace Catch::clara;
   // clang-format off
-  auto cli = session.cli() 
+  auto cli = session.cli()
     | Opt(cmd_options.iterations, "iterations")
         ["-I"]["--iterations"]
         ("Number of iterations used for performance tests (default: 1000)")
@@ -32,7 +32,16 @@ int main(int argc, char** argv) {
         ("Show progress bar when running performance tests")
     | Opt(cmd_options.cg_extended_run, "cg_extened_run")
         ["-E"]["--cg-extended-run"]
+        ("TODO: Description goes here")
+    | Opt(cmd_options.cg_iterations, "cg_iterations")
+        ["-C"]["--cg-iterations"]
         ("Number of iterations used for cooperative groups sync tests (default: 5)")
+    | Opt(cmd_options.accuracy_iterations, "accuracy_iterations")
+        ["-A"]["--accuracy-iterations"]
+        ("Number of iterations used for math accuracy tests with randomly generated inputs (default: 2^32)")
+    | Opt(cmd_options.accuracy_max_memory, "accuracy_max_memory")
+        ["-M"]["--accuracy-max-memory"]
+        ("Percentage of global device memory allowed for math accuracy tests (default: 80%)")
   ;
   // clang-format on
 
