@@ -187,9 +187,9 @@ __global__ void test_kernel_gfx11(unsigned int* atomic_val, unsigned int* array,
     // reach the atomicInc, but everyone will have only hit the atomic once.
     if (rank == (grid.size() - 1)) {
       long long time_diff = 0;
-      long long last_clock = wall_clock64();
+      long long last_clock = clock_function();
       do {
-        long long cur_clock = wall_clock64();
+        long long cur_clock = clock_function();
         if (cur_clock > last_clock) {
           time_diff += (cur_clock - last_clock);
         }
@@ -312,19 +312,19 @@ TEST_CASE("Unit_hipCGGridGroupType_Basic") {
     return;
   }
 
-  void* (*kernel_func)(void);
+  void* kernel_func;
 
   SECTION("Default grid group API test") {
-    kernel_func = reinterpret_cast<void* (*)()>(kernel_cg_grid_group_type);
+    kernel_func = reinterpret_cast<void*>(kernel_cg_grid_group_type);
   }
 #if HT_AMD
   SECTION("Base type grid group API test") {
-    kernel_func = reinterpret_cast<void* (*)()>(kernel_cg_grid_group_type_via_base_type);
+    kernel_func = reinterpret_cast<void*>(kernel_cg_grid_group_type_via_base_type);
   }
 #endif
 
   SECTION("Public API grid group test") {
-    kernel_func = reinterpret_cast<void* (*)()>(kernel_cg_grid_group_type_via_public_api);
+    kernel_func = reinterpret_cast<void*>(kernel_cg_grid_group_type_via_public_api);
   }
 
   // Test for block_size in powers of 2
