@@ -38,9 +38,22 @@ TEST_CASE("Unit_hipMemcpyAsync_Positive_Synchronization_Behavior") {
   using namespace std::placeholders;
   HIP_CHECK(hipDeviceSynchronize());
 
-  SECTION("Host memory to device memory") {
-    MemcpyHtoDSyncBehavior(std::bind(hipMemcpyAsync, _1, _2, _3, hipMemcpyHostToDevice, nullptr),
-                           true);
+  // This behavior differs on NVIDIA and AMD, on AMD the hipMemcpy calls is synchronous with
+  // respect to the host
+  SECTION("Host pageable memory to device memory") {
+#if HT_AMD
+    HipTest::HIP_SKIP_TEST(
+        "EXSWCPHIPT-127 - MemcpyAsync from host to device memory behavior differs on AMD and "
+        "Nvidia");
+    return;
+#endif
+    MemcpyHPageabletoDSyncBehavior(
+        std::bind(hipMemcpyAsync, _1, _2, _3, hipMemcpyHostToDevice, nullptr), false);
+  }
+
+  SECTION("Host pinned memory to device memory") {
+    MemcpyHPinnedtoDSyncBehavior(
+        std::bind(hipMemcpyAsync, _1, _2, _3, hipMemcpyHostToDevice, nullptr), false);
   }
 
   SECTION("Device memory to pageable host memory") {
@@ -66,6 +79,9 @@ TEST_CASE("Unit_hipMemcpyAsync_Positive_Synchronization_Behavior") {
   SECTION("Host memory to host memory") {
     MemcpyHtoHSyncBehavior(std::bind(hipMemcpyAsync, _1, _2, _3, hipMemcpyHostToHost, nullptr),
                            true);
+
+    MemcpyHPinnedtoHPinnedSyncBehavior(
+        std::bind(hipMemcpyAsync, _1, _2, _3, hipMemcpyHostToHost, nullptr), true);
   }
 }
 
