@@ -28,7 +28,7 @@ THE SOFTWARE.
 
 __global__ void tex2DKernel(float* outputData,
                             hipTextureObject_t textureObject, int width) {
-#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
+#if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
   outputData[y * width + x] = tex2D<float>(textureObject, x, y);
@@ -50,6 +50,11 @@ __global__ void tex2DKernel(float* outputData,
 TEST_CASE("Unit_hipTextureObj2D_Check") {
   CHECK_IMAGE_SUPPORT
 
+#if __HIP_NO_IMAGE_SUPPORT
+  HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
+  return;
+#endif
+
   constexpr int SIZE = 256;
   constexpr unsigned int width = SIZE;
   constexpr unsigned int height = SIZE;
