@@ -32,7 +32,7 @@ template<bool normalizedCoords>
 __global__ void tex2DKernel(float *outputData, hipTextureObject_t textureObject,
                             int width, int height, float offsetX,
                             float offsetY) {
-#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
+#if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
   outputData[y * width + x] = tex2D<float>(textureObject,
@@ -134,6 +134,11 @@ line1:
 TEST_CASE("Unit_hipTextureObj2DCheckModes") {
   CHECK_IMAGE_SUPPORT
 
+#if __HIP_NO_IMAGE_SUPPORT
+  HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
+  return;
+#endif
+
   SECTION("hipAddressModeClamp, hipFilterModePoint, regularCoords") {
     runTest<hipAddressModeClamp, hipFilterModePoint, false>(256, 256, -3.9, 6.1);
     runTest<hipAddressModeClamp, hipFilterModePoint, false>(256, 256, 4.4, -7.0);
